      subroutine user_evt1
c
c user pass 1 event routine
c
c this example user_evt1 routine, for each event, does the 
c following:
c - print the adc value from the selected channel
c - obtain the energy (adc - pedestal) of the selected channel
c   using the 3 available adc channel addressing systems
c - obtain the energy (adc - pedestal) of a cluster made of the
c   selected channel and the one above in eta
c - fill the ntuple with the energies
c - accumulate the moments for the pedestal covariance computation
c
      implicit none
c
c event trigger common
c user friendly trigger logical variables
c please read the comment in the *.inc file
c 
      include'../inc/hec_trig.inc'
c
c shared parameters common
c general constants
c please read the comment in the *.inc file
c
      include'../inc/hec_par.inc'
c
c geometry correspondence tables common (requires hec_par.inc)
c this is an important file, with lots of important comments on
c the adc channel addressing schemes.
c please read the comment in the *.inc file
c
      include'../inc/hec_geo.inc'
c
c adc values common (requires hec_par.inc)
c this is where the adc values are stored, for different adc channel
c addressing systems
c please read the comment in the *.inc file
c
      include'../inc/hec_adc.inc'
c
c pedestal values common (requires hec_par.inc)
c please read the comment in the *.inc file
c
      include'../inc/hec_ped.inc'
c
c user datacard values common
c this is where the user datacard values endup after the 
c initialisation phase has read the datacards
c please read the comment in the *.inc file
c
      include'./user_datacard.inc'
c
c user internal variables common
c this is where are the variables used to compute the pedestal
c variance between the picked channel and the one above in eta
c
      include'./user_common.inc'
c
c local variable declarations
c 
      real enic, endb, enph, encl
      real enph_b
      integer ic, i_mod, i_seg, i_pad, i_eta , i_phi ,i_z
      integer ic_b
      real x(4)
c
c user code
c
c get the picked channel from the user datacard values common
c ic_pick does not change from event to event, so the following
c is mainly pedagogical...
c
      ic = ic_pick
c
c get the database system coordinates of the selected channel
c
      i_mod = ictodb(ic, 1)
      i_seg = ictodb(ic, 2)
      i_pad = ictodb(ic, 3)
c
c get the physics system coordinates of the selected channel
c
      i_eta = ictoph(ic, 1)
      i_phi = ictoph(ic, 2)
      i_z   = ictoph(ic, 3)
c
c print the adc value of the selected channel, obtained from
c the adc arrays in the 3 addressing systems available
c they should all be the same!
c
      print *, 'ic = ', ic, 
     +         '    adc = ', i_adc_ic(ic),
     +                       i_adc_db(i_mod, i_seg, i_pad),
     +                       i_adc_ph(i_eta, i_phi, i_z)
c
c for physics trigger only,
c obtain the energy (adc - pedestal) for the selected channel
c again using the 3 addressing systems available
c
      if (trig_physics) then
        enic = real(i_adc_ic(ic)) - adc_ped(ic)
        endb = real(i_adc_db(i_mod, i_seg, i_pad)) - adc_ped(ic)
        enph = real(i_adc_ph(i_eta, i_phi, i_z)) - adc_ped(ic)
c
c obtain the energy (adc - pedestal) for a cluster made of the 
c selected channel and the one above in eta
c
        encl = enic
        if (i_eta + 1 .le. i_eta_used) then
          ic_b = phtoic(i_eta + 1, i_phi, i_z)
          enph_b = real(i_adc_ic(ic_b)) - adc_ped(ic_b)
          encl = encl + enph_b
        endif
c
c fill the ntuple 
c note that if all is ok, then enic=endb=enph !
c
        x(1) = enic
        x(2) = endb
        x(3) = enph
        x(4) = encl
        call hfn(1, x)
      endif
c
c for random triggers only, accumulate the pedestal moments
c needed to compute the covariance of the pedestal
c value between the two channels in the cluster
c
      if (trig_random) then
        if (i_eta + 1 .le. i_eta_used) then
          ic_b = phtoic(i_eta + 1, i_phi, i_z)
          m_0   = m_0   + 1
          m_1a  = m_1a  + i_adc_ic(ic)
          m_1b  = m_1b  + i_adc_ic(ic_b)
          m_2ab = m_2ab + i_adc_ic(ic)*i_adc_ic(ic_b)
        endif
      endif
c
      end







